@@ -1,6 +1,6 @@
 -- test-sort.hs -- example program, testing sort using LeanCheck
 --
--- Copyright (c) 2017-2020 Rudy Matela.
+-- Copyright (c) 2017-2024 Rudy Matela.
 -- Distributed under the 3-Clause BSD licence (see the file LICENSE).
 import Test.LeanCheck
 
@@ -13,18 +13,18 @@ sort (x:xs)  =  sort (filter (< x) xs)
 
 -- some properties about it --
 prop_sortOrdered :: Ord a => [a] -> Bool
-prop_sortOrdered xs = ordered (sort xs)
+prop_sortOrdered xs  =  ordered (sort xs)
   where
   ordered (x:y:xs)  =  x <= y && ordered (y:xs)
   ordered _         =  True
 
 prop_sortCount :: Ord a => a -> [a] -> Bool
-prop_sortCount x xs = count x (sort xs) == count x xs
+prop_sortCount x xs  =  count x (sort xs) == count x xs
   where
-  count x = length . filter (== x)
+  count x  =  length . filter (== x)
 
 main :: IO ()
-main = do
-  check $ (prop_sortOrdered :: [Int] -> Bool)
-  check $ (prop_sortCount :: Int -> [Int] -> Bool)
+main  =  do
+  check (prop_sortOrdered :: [Int] -> Bool)
+  check (prop_sortCount :: Int -> [Int] -> Bool)
   check $ \xs -> sort (sort xs :: [Int]) == sort xs
