@@ -1,6 +1,6 @@
 -- |
 -- Module      : Test.LeanCheck.Core
--- Copyright   : (c) 2015-2020 Rudy Matela
+-- Copyright   : (c) 2015-2024 Rudy Matela
 -- License     : 3-Clause BSD  (see the file LICENSE)
 -- Maintainer  : Rudy Matela <rudy@matela.com.br>
 --
@@ -76,8 +76,8 @@ module Test.LeanCheck.Core
   -- ** Misc utilities
   , (+|)
   , listIntegral
-  , tiersFractional
-  , tiersFloating
+  , listFractional
+  , listFloating
   )
 where
 
@@ -129,8 +129,9 @@ import Data.Maybe (listToMaybe)
 -- In this case, each sub-list in 'tiers' is a singleton list
 -- (each succeeding element of 'list' has +1 size).
 --
--- The function 'Test.LeanCheck.Derive.deriveListable' from "Test.LeanCheck.Derive"
--- can automatically derive instances of this typeclass.
+-- The function 'Test.LeanCheck.Derive.deriveListable'
+-- from "Test.LeanCheck.Derive" can automatically derive
+-- instances of this typeclass.
 --
 -- A 'Listable' instance for functions is also available but is not exported by
 -- default.  Import "Test.LeanCheck.Function" if you need to test higher-order
@@ -251,55 +252,44 @@ instance (Listable a) => Listable [a] where
   tiers  =  cons0 []
          \/ cons2 (:)
 
--- | Tiers of 'Fractional' values.
---   This can be used as the implementation of 'tiers' for 'Fractional' types.
+-- | Listing of 'Fractional' values.
+--   This can be used as the implementation of 'list' for 'Fractional' types.
 --
--- > tiersFractional :: [[Rational]]  =
--- >   [ [  0  % 1]
--- >   , [  1  % 1]
--- >   , [(-1) % 1]
--- >   , [  1  % 2,   2  % 1]
--- >   , [(-1) % 2, (-2) % 1]
--- >   , [  1  % 3,   3  % 1]
--- >   , [(-1) % 3, (-3) % 1]
--- >   , [  1  % 4,   2  % 3,   3  % 2,   4  % 1]
--- >   , [(-1) % 4, (-2) % 3, (-3) % 2, (-4) % 1]
--- >   , [  1  % 5,   5  % 1]
--- >   , [(-1) % 5, (-5) % 1]
--- >   , [  1  % 6,   2 % 5,    3  % 4,   4  % 3,   5  % 2,   6  % 1]
--- >   , [(-1) % 6, (-2) % 5, (-3) % 4, (-4) % 3, (-5) % 2, (-6) % 1]
--- >   , ...
--- >   ]
-tiersFractional :: Fractional a => [[a]]
-tiersFractional  =  mapT (\(x,y) -> fromInteger x / fromInteger y) . reset
-                 $  tiers `suchThat` \(n,d) -> d > 0 && n `gcd` d == 1
+-- > listFractional :: [[Rational]]  =
+-- >   [0 % 1, 1 % 1, (-1) % 1, 1 % 2, (-1) % 2, 2 % 1, (-2) % 1, 1 % 3, ...]
+--
+-- All rationals are included without repetition in their most simple form.
+-- This is the Calkin-Wilf sequence
+-- computed with the help of the @fusc@ function (EWD 570).
+--
+-- This also works for unsigned types that wrap around zero, yielding:
+--
+-- > listFractional :: [Ratio Word]  =
+-- >   [0 % 1, 1 % 1, 1 % 2, 2 % 1, 1 % 3, 3 % 2, 2 % 3, 3 % 1, 1 % 4, ...]
+listFractional :: (Ord a, Fractional a) => [a]
+listFractional  =  0 : positives +| negatives
+  where
+  stern  =  map (fromInteger . fusc) [1..]
+  positives  =  takeWhile (>0) $ zipWith (/) stern (drop 1 stern)
+  negatives  =  takeWhile (<0) $ map negate positives
+  fusc  =  fu 1 0  where  fu a b 0               =  b
+                          fu a b n  | even n     =  fu (a + b) b (n `div` 2)
+                                    | otherwise  =  fu a (a + b) ((n-1) `div` 2)
 
--- | Tiers of 'Floating' values.
---   This can be used as the implementation of 'tiers' for 'Floating' types.
+-- | Listing of 'Floating' values.
+--   This can be used as the implementation of 'list' for 'Floating' types.
 --
---   This function is equivalent to 'tiersFractional'
---   with positive and negative infinities included: 1/0 and -1/0.
+-- > listFloating :: [Double]  =
+-- >   [0.0, 1.0, -1.0, 0.5, -0.5, 2.0, Infinity, -Infinity, -2.0, 0.333, ...]
 --
--- > tiersFloating :: [[Float]]  =
--- >   [ [0.0]
--- >   , [1.0]
--- >   , [-1.0, Infinity]
--- >   , [ 0.5,  2.0, -Infinity]
--- >   , [-0.5, -2.0]
--- >   , [ 0.33333334,  3.0]
--- >   , [-0.33333334, -3.0]
--- >   , [ 0.25,  0.6666667,  1.5,  4.0]
--- >   , [-0.25, -0.6666667, -1.5, -4.0]
--- >   , [ 0.2,  5.0]
--- >   , [-0.2, -5.0]
--- >   , [ 0.16666667,  0.4,  0.75,  1.3333334,  2.5,  6.0]
--- >   , [-0.16666667, -0.4, -0.75, -1.3333334, -2.5, -6.0]
--- >   , ...
--- >   ]
+-- This follow the same Calkin-Wilf sequence of 'listFractional'
+-- but positive and negative infinities are artificially included after two.
 --
---   @NaN@ and @-0@ are excluded from this enumeration.
-tiersFloating :: Fractional a => [[a]]
-tiersFloating  =  tiersFractional \/ [ [], [], [1/0], [-1/0] {- , [-0], [0/0] -} ]
+-- @NaN@ and @-0@ are excluded from this enumeration.
+listFloating :: (Ord a, Fractional a) => [a]
+listFloating  =  heading ++ [two, 1/0, -1/0] ++ etc
+  where
+  (heading,two:etc)  =  span (< 2) listFractional
 
 -- | @NaN@ and @-0@ are not included in the list of 'Float's.
 --
@@ -312,13 +302,13 @@ tiersFloating  =  tiersFractional \/ [ [], [], [1/0], [-1/0] {- , [-0], [0/0] -}
 -- >   , ...
 -- >   ]
 instance Listable Float where
-  tiers  =  tiersFloating
+  list  =  listFloating
 
 -- | @NaN@ and @-0@ are not included in the list of 'Double's.
 --
 -- > list :: [Double]  =  [0.0, 1.0, -1.0, Infinity, 0.5, 2.0, ...]
 instance Listable Double where
-  tiers  =  tiersFloating
+  list  =  listFloating
 
 -- | > list :: [Ordering]  =  [LT, EQ, GT]
 instance Listable Ordering where
