@@ -1,21 +1,21 @@
--- Copyright (c) 2015-2020 Rudy Matela.
+-- Copyright (c) 2015-2024 Rudy Matela.
 -- Distributed under the 3-Clause BSD licence (see the file LICENSE).
-{-# OPTIONS_GHC -fno-warn-incomplete-patterns #-}
-import Test (getMaxTestsFromArgs)
+{-# LANGUAGE CPP #-}
 
-import System.Exit (exitFailure)
-import Data.List (elemIndices,sort)
+#if __GLASGOW_HASKELL__ >= 908
+{-# OPTIONS_GHC -Wno-x-partial #-}
+#endif
+
+{-# OPTIONS_GHC -fno-warn-incomplete-patterns #-}
+
+import Test (mainTest)
 
 import Test.LeanCheck.Error
 import Test.LeanCheck.Utils.Types (Nat)
+import Data.List (sort)
 
 main :: IO ()
-main  =  do
-  max <- getMaxTestsFromArgs 200
-  case elemIndices False (tests max) of
-    [] -> putStrLn "Tests passed!"
-    is -> do putStrLn ("Failed tests:" ++ show is)
-             exitFailure
+main  =  mainTest tests 200
 
 tests :: Int -> [Bool]
 tests n  =
@@ -107,25 +107,25 @@ tests n  =
   ]
 
 prop_sortMinE :: [Nat] -> Bool
-prop_sortMinE xs = head (sort xs) == minimum (xs::[Nat])
+prop_sortMinE xs  =  head (sort xs) == minimum (xs::[Nat])
 
 prop_sortMin :: [Nat] -> Bool
-prop_sortMin xs = not (null xs)
-              ==> head (sort xs) == minimum (xs::[Nat])
+prop_sortMin xs  =  not (null xs)
+                ==> head (sort xs) == minimum (xs::[Nat])
 
 someNumbers :: Int -> Bool
-someNumbers  2 = True
-someNumbers  3 = True
-someNumbers  5 = True
-someNumbers  7 = True
-someNumbers 11 = True
-someNumbers 13 = True
-someNumbers 17 = True
+someNumbers  2  =  True
+someNumbers  3  =  True
+someNumbers  5  =  True
+someNumbers  7  =  True
+someNumbers 11  =  True
+someNumbers 13  =  True
+someNumbers 17  =  True
 
 someOthers :: Int -> Int -> Bool
-someOthers = \x -> case x of 2 -> \y -> case y of 2 -> True
-                                                  4 -> True
-                                                  8 -> True
-                             3 -> \y -> case y of 3 -> True
-                                                  9 -> True
-                                                  27 -> True
+someOthers  =  \x -> case x of 2 -> \y -> case y of 2 -> True
+                                                    4 -> True
+                                                    8 -> True
+                               3 -> \y -> case y of 3 -> True
+                                                    9 -> True
+                                                    27 -> True
