@@ -1,18 +1,11 @@
--- Copyright (c) 2015-2020 Rudy Matela.
+-- Copyright (c) 2015-2024 Rudy Matela.
 -- Distributed under the 3-Clause BSD licence (see the file LICENSE).
 import Test
 
-import System.Exit (exitFailure)
-import Data.List (elemIndices)
 import Test.LeanCheck.Function ()
 
 main :: IO ()
-main  =  do
-  max <- getMaxTestsFromArgs 200
-  case elemIndices False (tests max) of
-    [] -> putStrLn "Tests passed!"
-    is -> do putStrLn ("Failed tests:" ++ show is)
-             exitFailure
+main  =  mainTest tests 200
 
 tests :: Int -> [Bool]
 tests n  =
@@ -37,7 +30,7 @@ prop_mapFilter :: (A -> A) -> (A -> Bool) -> [A] -> Bool
 prop_mapFilter f p xs  =  filter p (map f xs) == map f (filter p xs)
 
 prop_false :: (A -> A) -> (A -> A) -> Bool
-prop_false _ _ = False
+prop_false _ _  =  False
 
 prop_false' :: (A -> A) -> (A,A) -> Bool
-prop_false' _ _ = False
+prop_false' _ _  =  False
