@@ -1,10 +1,9 @@
 {-# LANGUAGE CPP #-}
--- Copyright (c) 2015-2020 Rudy Matela.
+-- Copyright (c) 2015-2024 Rudy Matela.
 -- Distributed under the 3-Clause BSD licence (see the file LICENSE).
 import Test
-import System.Exit (exitFailure)
-import Data.List (elemIndices,delete,isPrefixOf)
 import Test.LeanCheck.Utils.Types
+import Data.List (delete,isPrefixOf)
 import Data.Word
 import Data.Int
 import Data.Char hiding (Space)
@@ -13,19 +12,14 @@ import Data.Typeable (typeOf)
 #endif
 
 main :: IO ()
-main  =  do
-  max <- getMaxTestsFromArgs 200
-  case elemIndices False (tests max) of
-    [] -> putStrLn "Tests passed!"
-    is -> do putStrLn ("Failed tests:" ++ show is)
-             exitFailure
+main  =  mainTest tests 200
 
 
 -- | Given the number of bits, generates a range for signed/unsigned integers
 --   of that width.
 signedRange,unsignedRange :: (Num n) => Int -> [n]
-signedRange n   = map fromIntegral [-(2^(n-1))..(2^(n-1))-1]
-unsignedRange n = map fromIntegral [0..(2^n)-1]
+signedRange n    =  map fromIntegral [-(2^(n-1))..(2^(n-1))-1]
+unsignedRange n  =  map fromIntegral [0..(2^n)-1]
 
 tests :: Int -> [Bool]
 tests n =
@@ -154,7 +148,7 @@ tests n =
   , allTypeable || True
   ]
   where
-  unXs (Xs xs) = xs
+  unXs (Xs xs)  =  xs
 
 
 prefiX :: (Bounded a, Integral a) => [a]
@@ -202,10 +196,10 @@ prefiXNs =
   ]
 
 permutation :: Eq a => [a] -> [a] -> Bool
-[]     `permutation` []    = True
-(_:_)  `permutation` []    = False
-[]     `permutation` (_:_) = False
-(x:xs) `permutation` ys    = x `elem` ys  &&  xs `permutation` delete x ys
+[]     `permutation` []     =  True
+(_:_)  `permutation` []     =  False
+[]     `permutation` (_:_)  =  False
+(x:xs) `permutation` ys     =  x `elem` ys  &&  xs `permutation` delete x ys
 
 
 allTypeable :: Bool
